import sys
from PySide6.QtCore import QUrl
from PySide6.QtQml import QQmlApplicationEngine
from PySide6.QtWidgets import QApplication

if __name__ == "__main__":
    app = QApplication(sys.argv)

    qml_file = "main.qml"
    qml_url = QUrl.fromLocalFile(qml_file)
    qml_engine = QQmlApplicationEngine()

    # 加载QML文件并运行应用程序
    qml_engine.load(qml_url)

    if not qml_engine.rootObjects():
        sys.exit(-1)

    sys.exit(app.exec())


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-14 17:30
# @Author : 毛鹏
from PySide6.QtWidgets import QTabWidget

from mango_ui.settings.settings import THEME

class MangoTabs(QTabWidget):
    def __init__(self):
        super().__init__()
        self.setStyleSheet(f"""
            QTabWidget {{
                background-color: {THEME.dark_three}; /* 设置整个选项卡的底色 */
            }}
            QTabBar::tab {{
                border: none;  /* 去掉选项卡的边框 */
                padding: 10px; /* 内边距 */
            }}
            QTabBar::tab:selected {{
                background: {THEME.bg_three}; /* 选中时的背景颜色 */
            }}
            QTabBar::tab:hover {{
                background: {THEME.dark_three}; /* 鼠标悬停时的背景颜色 */
            }}
            QTabBar::tab {{                                
                border-right: 1px solid {THEME.dark_four}; /* 保留按钮之间的边框 */
            }}
            QTabBar::tab:last {{
                border-right: none; /* 最后一个选项卡不显示右边框 */
            }}
            QTabWidget::pane {{
                border: 1px solid {THEME.dark_four}; /* 底部横条 */
                border-left: none; /* 取消顶部边框 */
                border-right: none; /* 取消顶部边框 */
                border-bottom: none; /* 取消顶部边框 */
            }}
        """)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-08-30 14:52
# @Author : 毛鹏
from mango_ui.enums.enums import *
from mango_ui.init import *
from mango_ui.models.models import FormDataModel, DialogCallbackModel
from mango_ui.widgets import *


class DialogWidget(MangoDialog):
    clicked = Signal(object)

    def __init__(self, tips: str, form_data: list[FormDataModel], size: super = (400, 300)):
        super().__init__(tips, size)
        self.form_data = form_data
        form_layout = QFormLayout()
        for form in self.form_data:
            if form.type == InputEnum.INPUT:
                input_object = MangoLineEdit(form.placeholder, form.value, form.subordinate, key=form.key)
            elif form.type == InputEnum.SELECT:
                input_object = MangoComboBox(form.placeholder, form.select, form.value, form.subordinate, key=form.key)
            elif form.type == InputEnum.CASCADER:
                input_object = MangoCascade(form.placeholder, form.select, form.value, form.subordinate, key=form.key)
            elif form.type == InputEnum.TOGGLE:
                input_object = MangoToggle(form.value, key=form.key)
            elif form.type == InputEnum.SELECT_MANY:
                input_object = MangoComboBoxMany(form.placeholder, form.select, form.value)
            else:
                raise ValueError(f'类型错误: {form.type}')
            input_object.click.connect(self.entered)
            if form.required:
                form_layout.addRow(f"*{form.title}:", input_object)
            else:
                form_layout.addRow(f"{form.title}:", input_object)

            form.input_object = input_object

        self.layout.addLayout(form_layout)
        self.layout.addSpacerItem(QSpacerItem(20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding))
        button_layout = QHBoxLayout()
        button_layout.addStretch()
        cancel_button = MangoPushButton("取消", color=THEME.bg_one)
        cancel_button.clicked.connect(self.reject)
        button_layout.addWidget(cancel_button)
        submit_button = MangoPushButton("提交", color=THEME.blue)
        submit_button.clicked.connect(self.submit_form)
        button_layout.addWidget(submit_button)

        self.data = {}

    def submit_form(self):
        for form in self.form_data:
            value = form.input_object.get_value()
            if form.required:
                if value is None or value == '':
                    from mango_ui.components import error_message
                    self.data = {}
                    error_message(self, f'{form.title} 是必填项')
                    return
            if value == '':
                self.data[form.key] = None
            else:
                self.data[form.key] = value
        self.accept()  # 关闭对话框

    def entered(self, data: DialogCallbackModel):
        if isinstance(data, DialogCallbackModel):
            for i in self.form_data:
                if i.key == data.subordinate and i.key:
                    data.subordinate_input_object = i.input_object
                    data.key = i.key
                    self.clicked.emit(data)

    def check_value(self, value):
        pass



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-08 16:25
# @Author : 毛鹏
from enum import Enum


class InputEnum(Enum):
    INPUT = 0
    SELECT = 1
    CASCADER = 2
    TOGGLE = 3
    SELECT_MANY = 4


class StatusEnum(Enum):
    """状态枚举"""
    SUCCESS = 1
    FAIL = 0

    @classmethod
    def obj(cls):
        return {0: "关闭&进行中&失败", 1: "启用&已完成&通过"}


class Status1Enum(Enum):
    """状态枚举"""
    SUCCESS = 1
    FAIL = 0

    @classmethod
    def obj(cls):
        return {0: "否", 1: "是"}



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-04 17:32
# @Author : 毛鹏
from mango_ui.init import *
from mango_ui.models.models import ComboBoxDataModel, DialogCallbackModel


class MangoComboBoxMany(QComboBox):
    click = Signal(object)

    def __init__(self,
                 placeholder: str,
                 data: list[ComboBoxDataModel],
                 value: str,
                 theme: ThemeConfig = THEME,
                 parent=None):
        super().__init__(parent)
        self.dialog = None
        self.data = data
        self.parent = parent
        self.theme = theme.model_dump()

        self.setEditable(True)
        self.lineEdit().setReadOnly(True)
        self.list_widget = QListWidget()
        self.list_widget.setContentsMargins(0, 0, 0, 0)
        self.layout = QVBoxLayout()
        self.layout.setContentsMargins(0, 0, 0, 0)
        self.layout.addWidget(self.list_widget)
        self.populate_list_widget()
        if placeholder:
            self.lineEdit().setPlaceholderText(placeholder)
            # 设置默认选项
        if value is not None:
            self.set_value(value)
        self.set_stylesheet(self.theme)

    def populate_list_widget(self):
        for option in self.data:
            item = QListWidgetItem(option.name)
            item.setFlags(item.flags() | Qt.ItemIsUserCheckable)
            item.setCheckState(Qt.Unchecked)
            self.list_widget.addItem(item)

    def showPopup(self):
        if self.dialog is None:
            self.dialog = QDialog(self)
        else:
            self.dialog.setWindowTitle("选择项目")
            self.dialog.setFixedSize(200, 150)
            self.dialog.setLayout(self.layout)
            self.list_widget.itemChanged.connect(self.update_display)
            self.dialog.accepted.connect(self.update_display)
            self.dialog.exec()

    def update_display(self):
        selected_items = [self.list_widget.item(i).text() for i in range(self.list_widget.count()) if
                          self.list_widget.item(i).checkState() == Qt.Checked]
        if selected_items:
            self.lineEdit().setText(", ".join(selected_items))
        else:
            self.lineEdit().clear()
            self.lineEdit().setPlaceholderText("选择项目")

    def get_value(self):
        return [self.list_widget.item(i).text() for i in range(self.list_widget.count()) if
                self.list_widget.item(i).checkState() == Qt.Checked]

    def set_value(self, value):
        try:
            value_list = eval(value) if isinstance(value, str) else value
        except Exception:
            value_list = [value]
        for i in range(self.list_widget.count()):
            item = self.list_widget.item(i)
            if item.text() in value_list:
                item.setCheckState(Qt.Checked)
            else:
                item.setCheckState(Qt.Unchecked)
        selected_values = [item.text() for i in range(self.list_widget.count()) if
                           self.list_widget.item(i).checkState() == Qt.Checked]
        if selected_values:
            self.lineEdit().setText(", ".join(selected_values))
        else:
            self.lineEdit().clear()
            self.lineEdit().setPlaceholderText("选择项目")

        self.update_display()

    def set_stylesheet(self, style_config: dict, icon=':/icons/down.svg'):

        style = f'''
        QComboBox {{
            background-color: {style_config['white']};
            border-radius: {style_config['radius']}px;
            border: {style_config['border_size']}px solid gray;
            padding-left: 10px;
            padding-right: 10px;
            selection-color: {style_config['white']};
            selection-background-color: {style_config['context_color']};
            color: {style_config['text_foreground']};
        }}
        QComboBox:focus {{
            border: {style_config['border_size']}px solid {style_config['context_color']};
            background-color: {style_config['dark_three']};
        }}
        QComboBox::drop-down {{
            border: none;
            background-color: transparent;
            background-image: url({icon}); /* 使用背景图像 */
            background-repeat: no-repeat;
            background-position: center;
            width: 20px; /* 设置下拉按钮的宽度 */
        }}
        '''
        self.setStyleSheet(style)
        self.setMinimumHeight(30)  # 设置最小高度


class MangoComboBox(QComboBox):
    click = Signal(object)

    def __init__(
            self,
            placeholder: str,
            data: list[ComboBoxDataModel],
            value: int | str = None,
            subordinate: str | None = None,
            is_form: bool = True,
            theme: ThemeConfig = THEME,
            **kwargs,
    ):
        super().__init__()
        self.kwargs = kwargs
        self.placeholder = placeholder
        self.data = data
        self.value = value
        self.subordinate = subordinate
        self.is_form = is_form
        self.theme = theme.model_dump()
        # 设置样式表
        self.set_stylesheet(self.theme)
        self.currentIndexChanged.connect(self.combo_box_changed)
        self.set_select(self.data)
        self.setCurrentIndex(-1)
        self.set_value(self.value)
        if self.placeholder:
            self.setPlaceholderText(self.placeholder)

    def get_value(self):
        value = self.currentText()
        for i in self.data:
            if i.name == value:
                return i.id

    def set_select(self, data: list[ComboBoxDataModel], clear: bool = False):
        if clear:
            self.clear()
        if data:
            self.data = data
            self.addItems([i.name for i in data])

    def set_value(self, value: int | str):
        self.value = value
        if value is not None:
            for i in self.data:
                if i.id == value:
                    self.setCurrentText(i.name)
                    break
                else:
                    self.setCurrentText('')

    def combo_box_changed(self, data):
        if self.is_form:
            if self.subordinate:
                self.click.emit(DialogCallbackModel(
                    key=self.kwargs.get('key'),
                    value=self.get_value(),
                    subordinate=self.subordinate,
                    input_object=self
                ))
        else:
            self.click.emit(self.get_value())

    def set_stylesheet(self, style_config: dict, icon=':/icons/down.svg'):

        style = f'''
        QComboBox {{
            background-color: {style_config['white']};
            border-radius: {style_config['radius']}px;
            border: {style_config['border_size']}px solid gray;
            padding-left: 10px;
            padding-right: 10px;
            selection-color: {style_config['white']};
            selection-background-color: {style_config['context_color']};
            color: {style_config['text_foreground']};
        }}
        QComboBox:focus {{
            border: {style_config['border_size']}px solid {style_config['context_color']};
            background-color: {style_config['dark_three']};
        }}
        QComboBox::drop-down {{
            border: none;
            background-color: transparent;
            background-image: url({icon}); /* 使用背景图像 */
            background-repeat: no-repeat;
            background-position: center;
            width: 20px; /* 设置下拉按钮的宽度 */
        }}
        '''
        self.setStyleSheet(style)
        self.setMinimumHeight(30)  # 设置最小高度



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-04 14:35
# @Author : 毛鹏
from PySide6.QtCore import QPoint

from mango_ui.models.models import ResponseModel
from mango_ui.settings.settings import THEME
from mango_ui.widgets import *


def info_message(parent, text):
    message = MangoMessage(parent, text, THEME.pink)
    parent_pos = parent.mapToGlobal(QPoint(parent.width() // 2 - message.width() // 2, 0))
    message.move(parent_pos)
    message.show()


def success_message(parent, text):
    message = MangoMessage(parent, text, THEME.green)
    parent_pos = parent.mapToGlobal(QPoint(parent.width() // 2 - message.width() // 2, 0))
    message.move(parent_pos)
    message.show()


def warning_message(parent, text):
    message = MangoMessage(parent, text, THEME.yellow)
    parent_pos = parent.mapToGlobal(QPoint(parent.width() // 2 - message.width() // 2, 0))
    message.move(parent_pos)
    message.show()


def error_message(parent, text):
    message = MangoMessage(parent, text, THEME.red)
    parent_pos = parent.mapToGlobal(QPoint(parent.width() // 2 - message.width() // 2, 0))
    message.move(parent_pos)
    message.show()


def response_message(parent, response: ResponseModel):
    if response.code == 200:
        success_message(parent, response.msg)
    else:
        error_message(parent, response.msg)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-23 17:42
# @Author : 毛鹏
import numpy as np
import pyqtgraph as pg
from PySide6.QtWidgets import QVBoxLayout, QWidget


class MangoLinePlot(QWidget):
    def __init__(self, title, left, bottom):
        super().__init__()
        # 创建绘图窗口
        self.plot_widget = pg.PlotWidget()
        self.plot_widget.setBackground('w')  # 设置背景颜色为白色
        self.plot_widget.setTitle(title, color='b', size='20pt')
        self.plot_widget.setLabel('left', left, color='g', size='12pt')
        self.plot_widget.setLabel('bottom', bottom, color='g', size='12pt')
        self.plot_widget.addLegend()

        # 布局
        layout = QVBoxLayout()
        layout.setContentsMargins(0, 0, 0, 0)
        layout.addWidget(self.plot_widget)
        self.setLayout(layout)

    def draw(self, data: list[dict]):
        self.plot_widget.clear()

        days = np.arange(len(data[0]['value'])) + 1
        colors = ['b', 'r', 'g', 'c', 'm', 'y']

        for index, item in enumerate(data):
            color = colors[index % len(colors)]
            self.plot_widget.plot(
                days,
                item['value'],
                pen=color,
                name=item['name'],
                width=2,
                symbol='o',
                symbolBrush=color
            )



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-23 17:49
# @Author : 毛鹏
import matplotlib
import matplotlib.pyplot as plt
from PySide6.QtWidgets import QVBoxLayout, QWidget
from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas

# 设置字体为支持中文的字体
matplotlib.rcParams['font.family'] = 'SimHei'  # 或者 'Microsoft YaHei'
matplotlib.rcParams['axes.unicode_minus'] = False  # 显示负号


class MangoPiePlot(QWidget):
    def __init__(self):
        super().__init__()
        self.fig, self.ax = plt.subplots()
        self.canvas = FigureCanvas(self.fig)

        # 布局设置
        layout = QVBoxLayout()
        layout.setContentsMargins(0, 0, 0, 0)
        layout.addWidget(self.canvas)
        self.setLayout(layout)

    def draw(self, data: list[dict]):
        self.ax.clear()  # 清除之前的图
        sizes = [item['value'] for item in data]
        labels = [item['name'] for item in data]
        colors = ['#FF9999', '#66B3FF']
        self.ax.pie(sizes, labels=labels, colors=colors, autopct='%1.1f%%', startangle=90)
        self.ax.axis('equal')  # 确保饼状图是圆形
        self.canvas.draw()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-04 14:36
# @Author : 毛鹏
from PySide6.QtCore import QPoint

from mango_ui.settings.settings import THEME
from mango_ui.widgets import *


def success_notification(parent, text):
    notification = MangoNotification(parent, text, THEME.green)
    # 获取主窗口右上角位置
    parent_pos = parent.mapToGlobal(QPoint(parent.width() - notification.width() - 10, 20))
    notification.move(parent_pos)
    notification.show()


def info_notification(parent, text):
    notification = MangoNotification(parent, text, THEME.pink)
    # 获取主窗口右上角位置
    parent_pos = parent.mapToGlobal(QPoint(parent.width() - notification.width() - 10, 20))
    notification.move(parent_pos)
    notification.show()


def warning_notification(parent, text):
    notification = MangoNotification(parent, text, THEME.yellow)
    # 获取主窗口右上角位置
    parent_pos = parent.mapToGlobal(QPoint(parent.width() - notification.width() - 10, 20))
    notification.move(parent_pos)
    notification.show()


def error_notification(parent, text):
    notification = MangoNotification(parent, text, THEME.red)
    # 获取主窗口右上角位置
    parent_pos = parent.mapToGlobal(QPoint(parent.width() - notification.width() - 10, 20))
    notification.move(parent_pos)
    notification.show()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-08 16:12
# @Author : 毛鹏
from PySide6.QtWidgets import QWidget, QApplication

from mango_ui import *


class MyQWidget(QWidget):

    def __init__(self):
        super().__init__()
        self.layout = QVBoxLayout()
        self.layout.setContentsMargins(0, 0, 0, 0)
        self.layout.setSpacing(0)  # 设置间距为0
        self.resize(800, 400)
        self.layout_1 = QFormLayout()
        self.layout_1.addWidget(MangoPushButton('按钮'))
        self.layout_1.addWidget(MangoLabel('哈哈哈'))
        self.widget = MangoCard(self.layout_1)
        self.layout.addWidget(self.widget)
        self.layout.addWidget(MangoPushButton('2'))
        self.setLayout(self.layout)


if __name__ == '__main__':
    app = QApplication([])
    window = MyQWidget()
    window.show()
    app.exec()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from mango_ui.init import *
from .mango_div import MangoDiv
from .mango_title_button import MangoTitleButton

_is_maximized = False
_old_size = QSize()


class MangoTitleBar(QWidget):
    clicked = Signal(object)
    released = Signal(object)

    def __init__(
            self,
            parent,
            app_parent,
            logo_image=":/icons/app_icon.svg",
            dark_one=THEME.dark_one,
            bg_color=THEME.bg_two,
            div_color=THEME.bg_three,
            btn_bg_color=THEME.bg_two,
            btn_bg_color_hover=THEME.dark_three,
            btn_bg_color_pressed=THEME.bg_one,
            icon_color=THEME.icon_color,
            icon_color_hover=THEME.icon_hover,
            icon_color_pressed=THEME.icon_pressed,
            icon_color_active=THEME.icon_active,
            context_color=THEME.context_color,
            text_foreground=THEME.text_foreground,
            radius=8,
            font_family=THEME.font.family,
            title_size=THEME.font.title_size,
            is_custom_title_bar=True,
    ):
        super().__init__()

        self._logo_image = logo_image
        self._dark_one = dark_one
        self._bg_color = bg_color
        self._div_color = div_color
        self._parent = parent
        self._app_parent = app_parent
        self._btn_bg_color = btn_bg_color
        self._btn_bg_color_hover = btn_bg_color_hover
        self._btn_bg_color_pressed = btn_bg_color_pressed
        self._context_color = context_color
        self._icon_color = icon_color
        self._icon_color_hover = icon_color_hover
        self._icon_color_pressed = icon_color_pressed
        self._icon_color_active = icon_color_active
        self._font_family = font_family
        self._title_size = title_size
        self._text_foreground = text_foreground
        self._is_custom_title_bar = is_custom_title_bar

        self.title_bar_layout = QVBoxLayout(self)
        self.title_bar_layout.setContentsMargins(0, 0, 0, 0)

        self.bg = QFrame()

        self.bg_layout = QHBoxLayout(self.bg)
        self.bg_layout.setContentsMargins(10, 0, 5, 0)
        self.bg_layout.setSpacing(0)

        self.div_1 = MangoDiv(self._div_color)
        self.div_2 = MangoDiv(self._div_color)
        self.div_3 = MangoDiv(self._div_color)

        # 带移动应用程序的左框
        self.top_logo = QLabel()
        self.top_logo_layout = QVBoxLayout(self.top_logo)
        self.top_logo_layout.setContentsMargins(0, 0, 0, 0)

        self.logo_svg = QSvgWidget()
        self.logo_svg.load(self._logo_image)
        self.top_logo_layout.addWidget(self.logo_svg, Qt.AlignCenter, Qt.AlignCenter)

        # 标题标签
        self.title_label = QLabel()
        self.title_label.setAlignment(Qt.AlignVCenter)
        self.title_label.setStyleSheet(f'font: {self._title_size}pt "{self._font_family}"')

        # 自定义按钮布局
        self.custom_buttons_layout = QHBoxLayout()
        self.custom_buttons_layout.setContentsMargins(0, 0, 0, 0)
        self.custom_buttons_layout.setSpacing(3)

        # 最小化按钮
        self.minimize_button = MangoTitleButton(
            self._parent,
            self._app_parent,
            tooltip_text="收起",
            dark_one=self._dark_one,
            bg_color=self._btn_bg_color,
            bg_color_hover=self._btn_bg_color_hover,
            bg_color_pressed=self._btn_bg_color_pressed,
            icon_color=self._icon_color,
            icon_color_hover=self._icon_color_hover,
            icon_color_pressed=self._icon_color_pressed,
            icon_color_active=self._icon_color_active,
            context_color=self._context_color,
            text_foreground=self._text_foreground,
            radius=6,
            icon_path=":/icons/icon_minimize.svg"
        )

        # 最大化/恢复按钮
        self.maximize_restore_button = MangoTitleButton(
            self._parent,
            self._app_parent,
            tooltip_text="最大化",
            dark_one=self._dark_one,
            bg_color=self._btn_bg_color,
            bg_color_hover=self._btn_bg_color_hover,
            bg_color_pressed=self._btn_bg_color_pressed,
            icon_color=self._icon_color,
            icon_color_hover=self._icon_color_hover,
            icon_color_pressed=self._icon_color_pressed,
            icon_color_active=self._icon_color_active,
            context_color=self._context_color,
            text_foreground=self._text_foreground,
            radius=6,
            icon_path=":/icons/icon_maximize.svg"
        )

        # 关闭按钮
        self.close_button = MangoTitleButton(
            self._parent,
            self._app_parent,
            tooltip_text="关闭",
            dark_one=self._dark_one,
            bg_color=self._btn_bg_color,
            bg_color_hover=self._btn_bg_color_hover,
            bg_color_pressed=self._context_color,
            icon_color=self._icon_color,
            icon_color_hover=self._icon_color_hover,
            icon_color_pressed=self._icon_color_active,
            icon_color_active=self._icon_color_active,
            context_color=self._context_color,
            text_foreground=self._text_foreground,
            radius=6,
            icon_path=":/icons/icon_close.svg"
        )

        self.title_bar_layout.addWidget(self.bg)

        self.bg.setStyleSheet(f"background-color: {bg_color}; border-radius: {radius}px;")

        self.top_logo.setMinimumWidth(40)
        self.top_logo.setMaximumWidth(40)

        def moveWindow(event):
            # 如果最大化改变为正常
            if parent.isMaximized():
                self.maximize_restore()
                # self.resize(_old_size)
                curso_x = parent.pos().x()
                curso_y = event.globalPos().y() - QCursor.pos().y()
                parent.move(curso_x, curso_y)
            # 移动窗口
            if event.buttons() == Qt.LeftButton:
                parent.move(parent.pos() + event.globalPos() - parent.drag_pos)
                parent.drag_pos = event.globalPos()
                event.accept()

        # 移动应用程序小部件
        if is_custom_title_bar:
            self.top_logo.mouseMoveEvent = moveWindow
            self.div_1.mouseMoveEvent = moveWindow
            self.title_label.mouseMoveEvent = moveWindow
            self.div_2.mouseMoveEvent = moveWindow
            self.div_3.mouseMoveEvent = moveWindow

        # 最大化/恢复
        if is_custom_title_bar:
            self.top_logo.mouseDoubleClickEvent = self.maximize_restore
            self.div_1.mouseDoubleClickEvent = self.maximize_restore
            self.title_label.mouseDoubleClickEvent = self.maximize_restore
            self.div_2.mouseDoubleClickEvent = self.maximize_restore

        # 添加按钮按钮

        # 功能
        self.minimize_button.released.connect(lambda: parent.showMinimized())
        self.maximize_restore_button.released.connect(lambda: self.maximize_restore())
        self.close_button.released.connect(lambda: parent.close())

        # 添加控件到布局
        self.bg_layout.addWidget(self.top_logo)

        # 添加占位符 div_1
        self.bg_layout.addWidget(self.div_1)
        self.bg_layout.setStretch(self.bg_layout.indexOf(self.div_1), -1)  # 设置 div_1 的伸缩因子

        # 添加 title_label，靠近 top_logo
        self.bg_layout.addWidget(self.title_label)

        # 添加占位符 div_2
        self.bg_layout.addWidget(self.div_2)
        self.bg_layout.setStretch(self.bg_layout.indexOf(self.div_2), 1)  # 设置 div_2 的伸缩因子

        # 添加自定义按钮布局
        self.bg_layout.addLayout(self.custom_buttons_layout)

        # ADD Buttons
        if is_custom_title_bar:
            self.bg_layout.addWidget(self.minimize_button)
            self.bg_layout.addWidget(self.maximize_restore_button)
            self.bg_layout.addWidget(self.close_button)

    # 在标题栏中添加按钮
    # 添加btns并发出信号
    def add_menus(self, parameters):
        if parameters != None and len(parameters) > 0:
            for parameter in parameters:
                _btn_icon = parameter['btn_icon']
                _btn_id = parameter['btn_id']
                _btn_tooltip = parameter['btn_tooltip']
                _is_active = parameter['is_active']

                self.menu = MangoTitleButton(
                    self._parent,
                    self._app_parent,
                    btn_id=_btn_id,
                    tooltip_text=_btn_tooltip,
                    dark_one=self._dark_one,
                    bg_color=self._bg_color,
                    bg_color_hover=self._btn_bg_color_hover,
                    bg_color_pressed=self._btn_bg_color_pressed,
                    icon_color=self._icon_color,
                    icon_color_hover=self._icon_color_active,
                    icon_color_pressed=self._icon_color_pressed,
                    icon_color_active=self._icon_color_active,
                    context_color=self._context_color,
                    text_foreground=self._text_foreground,
                    icon_path=_btn_icon,
                    is_active=_is_active
                )
                self.menu.clicked.connect(self.btn_clicked)
                self.menu.released.connect(self.btn_released)

                self.custom_buttons_layout.addWidget(self.menu)

            if self._is_custom_title_bar:
                self.custom_buttons_layout.addWidget(self.div_3)

    # 标题栏菜单发出信号
    def btn_clicked(self):
        self.clicked.emit(self.menu)

    def btn_released(self):
        self.released.emit(self.menu)

    # 设置标题栏文本
    def set_title(self, title):
        self.title_label.setText(title)

    # 最大化并恢复父窗口
    def maximize_restore(self, e=None):
        global _is_maximized
        global _old_size

        # 更改UI并调整夹点大小
        def change_ui():
            if _is_maximized:
                self._parent.central_widget_layout.setContentsMargins(0, 0, 0, 0)
                self._parent.window.set_stylesheet(border_radius=0, border_size=0)
                self.maximize_restore_button.set_icon(":/icons/icon_restore.svg")
            else:
                self._parent.central_widget_layout.setContentsMargins(10, 10, 10, 10)
                self._parent.window.set_stylesheet(border_radius=10, border_size=2)
                self.maximize_restore_button.set_icon(":/icons/icon_maximize.svg")

        # 检查事件
        if self._parent.isMaximized():
            _is_maximized = False
            self._parent.showNormal()
            change_ui()
        else:
            _is_maximized = True
            _old_size = QSize(self._parent.width(), self._parent.height())
            self._parent.showMaximized()
            change_ui()



from PySide6.QtCore import *
from PySide6.QtWidgets import *


class LeftColumn:
    def setup_ui(self, left_column):
        left_column.resize(240, 600)
        self.main_pages_layout = QVBoxLayout(left_column)
        self.main_pages_layout.setSpacing(0)
        self.main_pages_layout.setContentsMargins(5, 5, 5, 5)
        self.menus = QStackedWidget(left_column)
        self.main_pages_layout.addWidget(self.menus)
        self.menus.setCurrentIndex(0)
        QMetaObject.connectSlotsByName(left_column)



import sys
import asyncio
from PySide6.QtCore import QObject, Signal, QTimer
from PySide6.QtWidgets import QApplication, QWidget, QVBoxLayout, QPushButton, QLabel


class AsyncWorker(QObject):
    finished = Signal()
    progress = Signal(str)

    async def do_async_work(self):
        for i in range(10):
            await asyncio.sleep(1)  # 模拟异步工作
            self.progress.emit(f"Progress: {i + 1} seconds")
        self.finished.emit()


class MyWidget(QWidget):
    def __init__(self):
        super().__init__()
        self.layout = QVBoxLayout()
        self.start_button = QPushButton("Start Async Work")
        self.progress_label = QLabel("Progress: 0 seconds")
        self.layout.addWidget(self.start_button)
        self.layout.addWidget(self.progress_label)
        self.setLayout(self.layout)

        self.worker = AsyncWorker()
        self.worker.progress.connect(self.update_progress)
        self.worker.finished.connect(self.async_task_finished)

        self.start_button.clicked.connect(self.start_async_task)

        self.timer = QTimer()
        self.timer.timeout.connect(self.run_pending)
        self.loop = asyncio.new_event_loop()  # 创建新的事件循环

    def start_async_task(self):
        print(1)
        self.timer.start(100)  # 每100毫秒检查一次
        asyncio.run_coroutine_threadsafe(self.worker.do_async_work(), self.loop)

    def run_pending(self):
        try:
            self.loop.run_until_complete(asyncio.sleep(0))  # 处理待处理的异步事件
        except Exception as e:
            print(f"Error: {e}")

    def update_progress(self, message):
        self.progress_label.setText(message)

    def async_task_finished(self):
        print(3)
        self.timer.stop()
        self.progress_label.setText("Task finished!")


# 创建 QApplication 实例
app = QApplication(sys.argv)

widget = MyWidget()
widget.show()

# 启动事件循环
app.exec()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-08-24 17:16
# @Author : 毛鹏
from mango_ui.init import *


class MangoCheckBox(QCheckBox):
    def __init__(self, text=None, parent=None):
        super().__init__(parent)
        self.setText(text)
        self.get_style()

    def get_style(self):
        # self.setStyleSheet()
        pass

    def isChecked(self):
        return super().isChecked()

    def setChecked(self, checked):
        super().setChecked(checked)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from mango_ui.init import *


class MangoGrips(QWidget):
    def __init__(self, parent, position, disable_color=True):
        super().__init__()
        self.parent = parent
        self.setParent(parent)
        self.wi = Widgets()

        if position == "top_left":
            self.wi.top_left(self)
            grip = QSizeGrip(self.wi.top_left_grip)
            grip.setFixedSize(self.wi.top_left_grip.size())
            self.setGeometry(5, 5, 15, 15)

            if disable_color:
                self.wi.top_left_grip.setStyleSheet("background: transparent")

        if position == "top_right":
            self.wi.top_right(self)
            grip = QSizeGrip(self.wi.top_right_grip)
            grip.setFixedSize(self.wi.top_right_grip.size())
            self.setGeometry(self.parent.width() - 20, 5, 15, 15)

            if disable_color:
                self.wi.top_right_grip.setStyleSheet("background: transparent")

        if position == "bottom_left":
            self.wi.bottom_left(self)
            grip = QSizeGrip(self.wi.bottom_left_grip)
            grip.setFixedSize(self.wi.bottom_left_grip.size())
            self.setGeometry(5, self.parent.height() - 20, 15, 15)

            if disable_color:
                self.wi.bottom_left_grip.setStyleSheet("background: transparent")

        if position == "bottom_right":
            self.wi.bottom_right(self)
            grip = QSizeGrip(self.wi.bottom_right_grip)
            grip.setFixedSize(self.wi.bottom_right_grip.size())
            self.setGeometry(self.parent.width() - 20, self.parent.height() - 20, 15, 15)

            if disable_color:
                self.wi.bottom_right_grip.setStyleSheet("background: transparent")

        if position == "top":
            self.wi.top(self)
            self.setGeometry(0, 5, self.parent.width(), 10)
            self.setMaximumHeight(10)

            def resize_top(event):
                delta = event.pos()
                height = max(self.parent.minimumHeight(), self.parent.height() - delta.y())
                geo = self.parent.geometry()
                geo.setTop(geo.bottom() - height)
                self.parent.setGeometry(geo)
                event.accept()

            self.wi.top_grip.mouseMoveEvent = resize_top

            if disable_color:
                self.wi.top_grip.setStyleSheet("background: transparent")


        elif position == "bottom":
            self.wi.bottom(self)
            self.setGeometry(0, self.parent.height() - 10, self.parent.width(), 10)
            self.setMaximumHeight(10)

            def resize_bottom(event):
                delta = event.pos()
                height = max(self.parent.minimumHeight(), self.parent.height() + delta.y())
                self.parent.resize(self.parent.width(), height)
                event.accept()

            self.wi.bottom_grip.mouseMoveEvent = resize_bottom

            if disable_color:
                self.wi.bottom_grip.setStyleSheet("background: transparent")

        elif position == "left":
            self.wi.left(self)
            self.setGeometry(0, 10, 10, self.parent.height())
            self.setMaximumWidth(10)

            def resize_left(event):
                delta = event.pos()
                width = max(self.parent.minimumWidth(), self.parent.width() - delta.x())
                geo = self.parent.geometry()
                geo.setLeft(geo.right() - width)
                self.parent.setGeometry(geo)
                event.accept()

            self.wi.left_grip.mouseMoveEvent = resize_left

            if disable_color:
                self.wi.left_grip.setStyleSheet("background: transparent")


        elif position == "right":
            self.wi.right(self)
            self.setGeometry(self.parent.width() - 10, 10, 10, self.parent.height())
            self.setMaximumWidth(10)

            def resize_right(event):
                delta = event.pos()
                width = max(self.parent.minimumWidth(), self.parent.width() + delta.x())
                self.parent.resize(width, self.parent.height())
                event.accept()

            self.wi.right_grip.mouseMoveEvent = resize_right

            if disable_color:
                self.wi.right_grip.setStyleSheet("background: transparent")

    # 鼠标释放
    def mouseReleaseEvent(self, event):
        self.mousePos = None

    # 调整事件大小
    def resizeEvent(self, event):
        if hasattr(self.wi, 'top_grip'):
            self.wi.top_grip.setGeometry(0, 0, self.width(), 10)

        elif hasattr(self.wi, 'bottom_grip'):
            self.wi.bottom_grip.setGeometry(0, 0, self.width(), 10)

        elif hasattr(self.wi, 'left_grip'):
            self.wi.left_grip.setGeometry(0, 0, 10, self.height() - 20)

        elif hasattr(self.wi, 'right_grip'):
            self.wi.right_grip.setGeometry(0, 0, 10, self.height() - 20)

        elif hasattr(self.wi, 'top_right_grip'):
            self.wi.top_right_grip.setGeometry(self.width() - 15, 0, 15, 15)

        elif hasattr(self.wi, 'bottom_left_grip'):
            self.wi.bottom_left_grip.setGeometry(0, self.height() - 15, 15, 15)

        elif hasattr(self.wi, 'bottom_right_grip'):
            self.wi.bottom_right_grip.setGeometry(self.width() - 15, self.height() - 15, 15, 15)


class Widgets:
    def top_left(self, form):
        self.top_left_grip = QFrame(form)
        self.top_left_grip.setObjectName(u"top_left_grip")
        self.top_left_grip.setFixedSize(15, 15)
        self.top_left_grip.setStyleSheet(u"background-color: #333; border: 2px solid #55FF00;")

    def top_right(self, form):
        self.top_right_grip = QFrame(form)
        self.top_right_grip.setObjectName(u"top_right_grip")
        self.top_right_grip.setFixedSize(15, 15)
        self.top_right_grip.setStyleSheet(u"background-color: #333; border: 2px solid #55FF00;")

    def bottom_left(self, form):
        self.bottom_left_grip = QFrame(form)
        self.bottom_left_grip.setObjectName(u"bottom_left_grip")
        self.bottom_left_grip.setFixedSize(15, 15)
        self.bottom_left_grip.setStyleSheet(u"background-color: #333; border: 2px solid #55FF00;")

    def bottom_right(self, form):
        self.bottom_right_grip = QFrame(form)
        self.bottom_right_grip.setObjectName(u"bottom_right_grip")
        self.bottom_right_grip.setFixedSize(15, 15)
        self.bottom_right_grip.setStyleSheet(u"background-color: #333; border: 2px solid #55FF00;")

    def top(self, form):
        self.top_grip = QFrame(form)
        self.top_grip.setObjectName(u"top_grip")
        self.top_grip.setGeometry(QRect(0, 0, 500, 10))
        self.top_grip.setStyleSheet(u"background-color: rgb(85, 255, 255);")
        self.top_grip.setCursor(QCursor(Qt.SizeVerCursor))

    def bottom(self, form):
        self.bottom_grip = QFrame(form)
        self.bottom_grip.setObjectName(u"bottom_grip")
        self.bottom_grip.setGeometry(QRect(0, 0, 500, 10))
        self.bottom_grip.setStyleSheet(u"background-color: rgb(85, 170, 0);")
        self.bottom_grip.setCursor(QCursor(Qt.SizeVerCursor))

    def left(self, form):
        self.left_grip = QFrame(form)
        self.left_grip.setObjectName(u"left")
        self.left_grip.setGeometry(QRect(0, 10, 10, 480))
        self.left_grip.setMinimumSize(QSize(10, 0))
        self.left_grip.setCursor(QCursor(Qt.SizeHorCursor))
        self.left_grip.setStyleSheet(u"background-color: rgb(255, 121, 198);")

    def right(self, form):
        self.right_grip = QFrame(form)
        self.right_grip.setObjectName(u"right")
        self.right_grip.setGeometry(QRect(0, 0, 10, 500))
        self.right_grip.setMinimumSize(QSize(10, 0))
        self.right_grip.setCursor(QCursor(Qt.SizeHorCursor))
        self.right_grip.setStyleSheet(u"background-color: rgb(255, 0, 127);")



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-30 14:08
# @Author : 毛鹏
from functools import partial

from mango_ui.init import *
from mango_ui.models.models import RightDataModel
from mango_ui.widgets import *


class RightButton(QWidget):
    clicked = Signal(object)

    def __init__(self, but_list_obj: list[RightDataModel]):
        super().__init__()
        self.but_list_obj = but_list_obj
        self.layout = QHBoxLayout()
        self.layout.setContentsMargins(0, 0, 0, 0)
        self.layout.addStretch()
        for but_obj in self.but_list_obj:
            but_obj.obj = MangoPushButton(but_obj.name, color=but_obj.theme)
            but_obj.obj.clicked.connect(partial(self.but_clicked, but_obj.action))
            self.layout.addWidget(but_obj.obj)
        self.setLayout(self.layout)

    def but_clicked(self, action):
        self.clicked.emit({'action': action, 'row': None})



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-29 11:25
# @Author : 毛鹏
from typing import Optional

from mango_ui.models.models import TreeModel
from mango_ui.init import *


class MangoTree(QTreeWidget):
    clicked = Signal(TreeModel)

    def __init__(self,
                 title: str,
                 parent=None):
        super().__init__(parent)
        self.data: Optional[list[TreeModel] | None] = None
        self.setHeaderLabels([title])
        self.itemClicked.connect(self.on_item_clicked)
        self.set_stylesheet()

    def on_item_clicked(self, item, column):
        if item.childCount() > 0:
            item.setExpanded(not item.isExpanded())
        else:
            self.clicked.emit(item.data(0, Qt.UserRole))  # type: ignore

    def set_item(self, items: list[TreeModel]):
        self.data = items
        for item in items:
            parent_item = QTreeWidgetItem(self)
            parent_item.setText(0, item.title)
            parent_item.setData(0, Qt.UserRole, item)  # type: ignore
            if item.children:
                for i in item.children:
                    child_item = QTreeWidgetItem(parent_item)
                    child_item.setText(0, i.title)  # type: ignore
                    child_item.setData(0, Qt.UserRole, i)  # type: ignore

    def set_stylesheet(self):
        style = f"""
            MangoTree {{
                background-color: {THEME.white};
                border-radius: {THEME.radius}px;
                border: {THEME.border_size}px solid gray;
                color: {THEME.text_foreground};
            }}
        
            MangoTree::item {{
                padding: 5px;
                background-color: {THEME.white};
                color: {THEME.text_foreground};
            }}
        
            MangoTree::item:selected {{
                background-color: {THEME.context_color};
                color: {THEME.white};
            }}
        
            MangoTree::item:hover {{
                background-color: {THEME.dark_three};
            }}
            QHeaderView {{
                font-size: 14px;  /* 修改字体大小 */

            }}
        """
        self.setStyleSheet(style)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-05 16:24
# @Author : 毛鹏

from mango_ui.init import *
from mango_ui.models.models import CascaderModel, DialogCallbackModel


class MangoCascade(QToolButton):
    click = Signal(object)

    def __init__(self,
                 placeholder: str,
                 data: list[CascaderModel],
                 value: int = None,
                 subordinate: str | None = None,
                 theme: ThemeConfig = THEME,
                 **kwargs
                 ):
        super().__init__()
        self.placeholder = placeholder
        self.data: list[CascaderModel] = data
        self.subordinate: str = subordinate
        self.value: int = value
        self.theme = theme.model_dump()
        self.kwargs = kwargs
        self.set_stylesheet(self.theme)
        # 创建工具按钮
        self.setPopupMode(QToolButton.InstantPopup)
        self.menu = QMenu()
        self.set_select(self.data)
        self.set_value(self.value)
        self.setMenu(self.menu)
        self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
        self.is_text = False

    def set_text(self, text: str):
        self.menu.clear()
        self.setText(text)
        self.is_text = True

    def show_selection(self, category, value, label):
        self.setText(f'{category}/{label}')
        self.value = value
        if self.subordinate:
            self.click.emit(DialogCallbackModel(
                key=self.kwargs.get('key'),
                value=value,
                subordinate=self.subordinate,
                input_object=self
            ))

    def get_value(self):
        if self.is_text:
            return None
        return self.value

    def set_select(self, data: list[CascaderModel], clear: bool = False):
        self.setText('')
        self.is_text = False
        if clear:
            self.menu.clear()
        if data is None:
            return
        self.data = data
        for cascade in self.data:
            fruits_menu = QMenu(cascade.label, self)
            if cascade.children:
                for fruit in cascade.children:
                    action = fruits_menu.addAction(fruit.label)
                    action.triggered.connect(
                        lambda checked, value=fruit.value, label=fruit.label: self.show_selection(cascade.label,
                                                                                                  value,
                                                                                                  label))
            self.menu.addMenu(fruits_menu)

    def set_value(self, value: int):
        if self.data is None:
            return
        self.value = value
        for i in self.data:
            for e in i.children:
                if e.value == value:
                    self.setText(f'{i.label}/{e.label}')

    def set_stylesheet(self, style_config):
        style = f'''
              QToolButton {{
                  background-color: {style_config['white']}; /* 按钮背景颜色 */
                  border-radius: {style_config['radius']}px; /* 按钮圆角半径 */
                  border: {style_config['border_size']}px solid gray; /* 按钮边框样式 */
                  padding-left: 10px;
                  padding-right: 10px;
                  padding: 5px; /* 按钮内边距 */
                  color: {style_config['text_foreground']};
              }}

              QToolButton:focus {{
                  border: 1px solid {style_config['dark_four']}; /* 焦点时边框颜色 */
                  background-color: {style_config['bg_one']}; /* 焦点时背景颜色 */
              }}

              QToolButton::menu-indicator {{
                  image: url(:/icons/down.svg); /* 下拉指示器图像 */
              }}

              QMenu {{
                  background-color: white; /* 菜单背景颜色 */
                  border: 1px solid gray; /* 菜单边框样式 */
                  padding: 0; /* 菜单内边距 */
              }}

              QMenu::item {{
                  padding: 10px 15px; /* 菜单项的内边距 */
                  color: black; /* 菜单项字体颜色 */
              }}

              QMenu::item:selected {{
                  background-color: {style_config['dark_four']}; /* 选中菜单项的背景颜色 */
                  color: white; /* 选中菜单项的字体颜色 */
              }}
              '''
        self.setStyleSheet(style)



import sys
from PySide6.QtWidgets import QApplication, QVBoxLayout, QWidget, QMessageBox

from mango_ui import TreeModel
from mango_ui.widgets.window.mango_tree import MangoTree


class ExpandableListWidget(QWidget):
    def __init__(self):
        super().__init__()
        layout = QVBoxLayout()
        self.tree_widget = MangoTree('测试')
        self.tree_widget.clicked.connect(self.on_child_item_clicked)
        data = [TreeModel(**i) for i in [{
            "title": "演示-登录退出场景1",
            "status": 1,
            "key": "{\"test_suite_id\":424314712861,\"ui_case_result\":70,\"case_id\":11}",
            "children": [
                {
                    "title": "普通权限用户登录1",
                    "status": 1,
                    "key": "{\"test_suite_id\":424314712861,\"page_steps_result\":107,\"case_id\":11,\"page_step_id\":15}",
                    "children": []
                },
                {
                    "title": "用户退出登录1",
                    "status": 1,
                    "key": "{\"test_suite_id\":424314712861,\"page_steps_result\":108,\"case_id\":11,\"page_step_id\":16}",
                    "children": []
                }
            ]
        }, {
            "title": "演示-登录退出场景2",
            "status": 1,
            "key": "{\"test_suite_id\":424314712861,\"ui_case_result\":70,\"case_id\":11}",
            "children": [
                {
                    "title": "普通权限用户登录2",
                    "status": 1,
                    "key": "{\"test_suite_id\":424314712861,\"page_steps_result\":107,\"case_id\":11,\"page_step_id\":15}",
                    "children": []
                },
                {
                    "title": "用户退出登录2",
                    "status": 1,
                    "key": "{\"test_suite_id\":424314712861,\"page_steps_result\":108,\"case_id\":11,\"page_step_id\":16}",
                    "children": []
                }
            ]
        }]]
        self.tree_widget.set_item(data)
        layout.addWidget(self.tree_widget)
        self.setLayout(layout)

    def on_child_item_clicked(self, model: TreeModel):
        # 处理子项点击信号，model 是整个 TreeModel 对象
        QMessageBox.information(self, "子项点击", f"你点击了: {model.title}\n状态: {model.status}\n键: {model.key}")


if __name__ == "__main__":
    app = QApplication(sys.argv)
    window = ExpandableListWidget()
    window.resize(300, 200)
    window.show()
    sys.exit(app.exec())



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-15 14:28
# @Author : 毛鹏
from PySide6.QtWidgets import QTimeEdit

from mango_ui.settings.settings import THEME


class MangoTimeEdit(QTimeEdit):
    def __init__(self, parent=None):
        super().__init__(parent)
        self.set_style()

    def set_style(self, height=30):
        self.setStyleSheet(f"""
            QTimeEdit {{
                background-color: {THEME.white};
                border-radius: {THEME.radius}px;
                border: {THEME.border_size}px solid gray;
                padding-left: 10px;
                padding-right: 10px;
                selection-color: {THEME.white};
                selection-background-color: {THEME.context_color};
                color: {THEME.text_foreground};
        }}
        
        QTimeEdit:focus {{
            border: {THEME.border_size}px solid {THEME.context_color};
            background-color: {THEME.dark_three};
        }}
        QTimeEdit::up-button, QTimeEdit::down-button {{
            border: none; /* 去掉边框 */
            background: transparent; /* 背景透明 */
            width: 0; /* 设置宽度为0 */
            height: 0; /* 设置高度为0 */
            margin: 0; /* 去掉外边距 */
            padding: 0; /* 去掉内边距 */
        }}
        """)
        self.setMinimumHeight(height)



import sys
from PySide6.QtWidgets import QApplication, QWidget, QVBoxLayout
from mango_ui import *
from tests.异步支持1 import QComboCheckBox


class MainWindow(QWidget):
    def __init__(self):
        super().__init__()
        self.setWindowTitle("Custom Tabs Example")
        self.setGeometry(100, 100, 400, 300)

        layout = QVBoxLayout()
        self.tab_widget = QComboCheckBox()
        self.tab_widget.addItems(['选项1', '选项2', '选项3'])
        self.but = MangoPushButton('点击')
        self.but.clicked.connect(self.button_clicked)
        layout.addWidget(self.tab_widget)
        layout.addWidget(self.but)

        self.setLayout(layout)

    def button_clicked(self):
        print(self.tab_widget.get_text())


if __name__ == "__main__":
    app = QApplication(sys.argv)
    window = MainWindow()
    window.show()
    sys.exit(app.exec())



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from mango_ui.enums.enums import StatusEnum
from mango_ui.init import *
from mango_ui.models.models import ComboBoxDataModel


class MangoToggle(QCheckBox):
    click = Signal(object)
    change_requested = Signal(object)

    def __init__(self, value=False, auto_update_status=True, theme=THEME, **kwargs):
        super().__init__()
        self.value = value
        self.kwargs = kwargs
        self.auto_update_status = auto_update_status
        self.data = [ComboBoxDataModel(id=i.get('id'), name=i.get('name')) for i in [
            {'id': 0, 'name': '关闭&进行中&失败'}, {'id': 1, 'name': '启用&已完成&通过'}]]
        self.theme = theme
        self.setFixedSize(50, 28)
        self.setCursor(Qt.PointingHandCursor)

        self._position = 3
        self.animation = QPropertyAnimation(self, b"position")
        self.animation.setEasingCurve(QEasingCurve.OutBounce)
        self.animation.setDuration(500)
        self.clicked.connect(self.on_clicked)
        self.stateChanged.connect(self.set_animation)
        self.set_value(self.value)
        self.change_requested.connect(self.set_animation)

    def get_value(self) -> int:
        return int(self.isChecked())

    def set_value(self, value: bool | StatusEnum):
        if value is None:
            return
        if isinstance(value, StatusEnum):
            self.value = bool(value)
        else:
            self.value = value
        self.setChecked(self.value)

    @Property(float)
    def position(self):
        return self._position

    @position.setter
    def position(self, pos):
        self._position = pos
        self.update()

    def on_clicked(self, value):
        if self.auto_update_status:
            self.set_value(value)
        self.click.emit({'value': int(self.isChecked())})

    def set_animation(self, value):
        self.animation.stop()
        if self.isChecked():
            self.animation.setEndValue(self.width() - 27)
        else:
            self.animation.setEndValue(3)
        self.animation.start()
    def hitButton(self, pos: QPoint):
        return self.contentsRect().contains(pos)

    def paintEvent(self, e):
        p = QPainter(self)
        p.setRenderHint(QPainter.Antialiasing)
        p.setFont(QFont("Segoe UI", 9))
        p.setPen(Qt.NoPen)
        rect = QRect(0, 0, self.width(), self.height())
        if self.isChecked():
            p.setBrush(QColor(self.theme.green))
            p.drawRoundedRect(0, 0, rect.width(), 28, 14, 14)
            p.setBrush(QColor(self.theme.dark_one))
            p.drawEllipse(self._position, 3, 22, 22)
        else:
            p.setBrush(QColor(self.theme.dark_two))
            p.drawRoundedRect(0, 0, rect.width(), 28, 14, 14)
            p.setBrush(QColor(self.theme.dark_one))
            p.drawEllipse(self._position, 3, 22, 22)
        p.end()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-08-24 17:08
# @Author : 毛鹏
from mango_ui.init import *


class MangoLabel(QLabel):
    def __init__(self, text=None, parent=None):
        """
        标签构造函数。

        参数：
        - text：标签显示的文本。
        """
        super().__init__(parent)
        self.setStyleSheet("background-color: transparent; color: black;")
        self.setText(str(text))

    def setText(self, text):
        """
        设置标签的文本内容。

        参数：
        - text：要设置的文本。
        """
        super().setText(str(text))

    def text(self):
        """
        获取标签的文本内容。

        返回值：
        - 当前标签的文本。
        """
        return super().text()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-08 16:23
# @Author : 毛鹏
from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *
from PySide6.QtSvgWidgets import *
from mango_ui.resources.app_rc import *
from mango_ui.settings.settings import *



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from mango_ui.init import *


class MangoCircularProgress(QWidget):
    def __init__(self, parent, value=0, progress_width=10, is_rounded=True, max_value=100,
                 progress_color=THEME.context_color, enable_text=True, font_family="微软雅黑", font_size=12, suffix="%",
                 text_color=THEME.text_title, enable_bg=True, bg_color=THEME.dark_four, *args, **kwargs):
        QWidget.__init__(self)

        super().__init__(parent, *args, **kwargs)
        self.value = value
        self.progress_width = progress_width
        self.progress_rounded_cap = is_rounded
        self.max_value = max_value
        self.progress_color = progress_color
        self.enable_text = enable_text
        self.font_family = font_family
        self.font_size = font_size
        self.suffix = suffix
        self.text_color = text_color
        self.enable_bg = enable_bg
        self.bg_color = bg_color

    def add_shadow(self, enable):
        if enable:
            self.shadow = QGraphicsDropShadowEffect(self)
            self.shadow.setBlurRadius(15)
            self.shadow.setXOffset(0)
            self.shadow.setYOffset(0)
            self.shadow.setColor(QColor(0, 0, 0, 80))
            self.setGraphicsEffect(self.shadow)

    def set_value(self, value):
        self.value = value
        self.repaint()

    def paintEvent(self, e):
        width = self.width() - self.progress_width
        height = self.height() - self.progress_width
        margin = self.progress_width / 2
        value = self.value * 360 / self.max_value

        paint = QPainter()
        paint.begin(self)
        paint.setRenderHint(QPainter.Antialiasing)
        paint.setFont(QFont(self.font_family, self.font_size))

        rect = QRect(0, 0, self.width(), self.height())
        paint.setPen(Qt.NoPen)

        pen = QPen()
        pen.setWidth(self.progress_width)
        if self.progress_rounded_cap:
            pen.setCapStyle(Qt.RoundCap)

        if self.enable_bg:
            pen.setColor(QColor(self.bg_color))
            paint.setPen(pen)
            paint.drawArc(margin, margin, width, height, 0, 360 * 16)

        pen.setColor(QColor(self.progress_color))
        paint.setPen(pen)
        paint.drawArc(margin, margin, width, height, -90 * 16, -value * 16)

        if self.enable_text:
            pen.setColor(QColor(self.text_color))
            paint.setPen(pen)
            paint.drawText(rect, Qt.AlignCenter, f"{self.value}{self.suffix}")

        paint.end()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-14 21:13
# @Author : 毛鹏
from PySide6.QtCore import Qt
from PySide6.QtWidgets import QScrollArea, QWidget, QVBoxLayout

from mango_ui.settings.settings import THEME


class MangoScrollArea(QScrollArea):

    def __init__(self, parent=None):
        super().__init__(parent)
        self.setWidgetResizable(True)
        self.scroll_widget = QWidget()
        self.setWidget(self.scroll_widget)
        self.layout = QVBoxLayout(self.scroll_widget)
        self.layout.setContentsMargins(0, 0, 0, 0)
        self.scroll_widget.setLayout(self.layout)
        self.layout.setAlignment(Qt.AlignTop)

        # self.setStyleSheet(f"background-color: {THEME.white}")
        self.setStyleSheet(f"""
                QScrollArea {{
            background-color: {THEME.dark_three};
            padding: 5px;
            border-radius: {THEME.radius}px;
            border: 1px solid {THEME.bg_three};
        }}
        
        QScrollBar:horizontal {{
            border: none;
            background: {THEME.bg_one};
            height: 8px;
            margin: 0px 21px;
            border-radius: 0px;
        }}
        
        QScrollBar::handle:horizontal {{
            background: {THEME.context_hover};
            min-width: 25px;
            border-radius: 4px;
        }}
        
        QScrollBar::add-line:horizontal {{
            border: none;
            background: {THEME.dark_four};
            width: 20px;
            border-top-right-radius: 4px;
            border-bottom-right-radius: 4px;
            subcontrol-position: right;
            subcontrol-origin: margin;
        }}
        
        QScrollBar::sub-line:horizontal {{
            border: none;
            background: {THEME.dark_four};
            width: 20px;
            border-top-left-radius: 4px;
            border-bottom-left-radius: 4px;
            subcontrol-position: left;
            subcontrol-origin: margin;
        }}
        
        QScrollBar::up-arrow:horizontal, QScrollBar::down-arrow:horizontal {{
            background: none;
        }}
        
        QScrollBar::add-page:horizontal, QScrollBar::sub-page:horizontal {{
            background: none;
        }}
        
        QScrollBar:vertical {{
            border: none;
            background: {THEME.bg_one};
            width: 8px;
            margin: 21px 0;
            border-radius: 0px;
        }}
        
        QScrollBar::handle:vertical {{
            background: {THEME.context_hover};
            min-height: 25px;
            border-radius: 4px;
        }}
        
        QScrollBar::add-line:vertical {{
            border: none;
            background: {THEME.dark_four};
            height: 20px;
            border-bottom-left-radius: 4px;
            border-bottom-right-radius: 4px;
            subcontrol-position: bottom;
            subcontrol-origin: margin;
        }}
        
        QScrollBar::sub-line:vertical {{
            border: none;
            background: {THEME.dark_four};
            height: 20px;
            border-top-left-radius: 4px;
            border-top-right-radius: 4px;
            subcontrol-position: top;
            subcontrol-origin: margin;
        }}

        """)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 布局
# @Time   : 2024-09-19 16:43
# @Author : 毛鹏
from PySide6.QtWidgets import QVBoxLayout, QHBoxLayout, QFormLayout, QGridLayout, QWidget, QApplication



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏

from mango_ui.init import *


class MangoWindow(QFrame):
    style = """
        #pod_bg_app {{
            background-color: {_bg_color};
            border-radius: {_border_radius};
            border: {_border_size}px solid {_border_color};
        }}
        QFrame {{ 
            color: {_text_color};
            font: {_text_font};
        }}
        """

    def __init__(
            self,
            parent,
            layout=Qt.Vertical,
            margin=0,
            spacing=2,
            bg_color=THEME.bg_one,
            text_color=THEME.text_foreground,
            text_font="9pt 'Segoe UI'",
            border_radius=10,
            border_size=2,
            border_color=THEME.bg_two,
            enable_shadow=True
    ):
        super().__init__()
        self.parent = parent
        self.layout = layout
        self.margin = margin
        self.bg_color = bg_color
        self.text_color = text_color
        self.text_font = text_font
        self.border_radius = border_radius
        self.border_size = border_size
        self.border_color = border_color
        self.enable_shadow = enable_shadow

        self.setObjectName("pod_bg_app")

        self.set_stylesheet()

        if layout == Qt.Vertical:
            self.layout = QHBoxLayout(self)
        else:
            self.layout = QHBoxLayout(self)
        self.layout.setContentsMargins(margin, margin, margin, margin)
        self.layout.setSpacing(spacing)

        if enable_shadow:
            self.shadow = QGraphicsDropShadowEffect()
            self.shadow.setBlurRadius(20)
            self.shadow.setXOffset(0)
            self.shadow.setYOffset(0)
            self.shadow.setColor(QColor(0, 0, 0, 160))
            self.setGraphicsEffect(self.shadow)

    def set_stylesheet(
            self,
            bg_color=None,
            border_radius=None,
            border_size=None,
            border_color=None,
            text_color=None,
            text_font=None
    ):
        if bg_color != None:
            internal_bg_color = bg_color
        else:
            internal_bg_color = self.bg_color

        if border_radius != None:
            internal_border_radius = border_radius
        else:
            internal_border_radius = self.border_radius

        if border_size != None:
            internal_border_size = border_size
        else:
            internal_border_size = self.border_size

        if text_color != None:
            internal_text_color = text_color
        else:
            internal_text_color = self.text_color

        #  检查文本颜色
        if border_color != None:
            internal_border_color = border_color
        else:
            internal_border_color = self.border_color

        if text_font != None:
            internal_text_font = text_font
        else:
            internal_text_font = self.text_font

        self.setStyleSheet(self.style.format(
            _bg_color=internal_bg_color,
            _border_radius=internal_border_radius,
            _border_size=internal_border_size,
            _border_color=internal_border_color,
            _text_color=internal_text_color,
            _text_font=internal_text_font
        ))



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-30 14:08
# @Author : 毛鹏
# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-30 14:08
# @Author : 毛鹏
from mango_ui.models.models import FieldListModel
from mango_ui.widgets import *


class TitleInfoWidget(QWidget):

    def __init__(self):
        super().__init__()
        self.field_list = None
        self.raw_data = None
        self.layout = QHBoxLayout()
        self.layout.setContentsMargins(0, 0, 0, 0)
        self.grid_layout = QGridLayout()
        self.mango_card = MangoCard(self.grid_layout)
        self.layout.addWidget(self.mango_card)
        self.setLayout(self.layout)

    def init(self, raw_data: dict, field_list: list[FieldListModel]):
        if self.field_list is None and self.raw_data is None:
            self.field_list = field_list
            self.raw_data = raw_data
            row = 0
            column = 0
            for index, item in enumerate(self.field_list):
                if self.raw_data[item.key] and isinstance(self.raw_data[item.key], dict):
                    value = self.raw_data[item.key].get('name')
                else:
                    value = self.raw_data[item.key]
                self.grid_layout.addWidget(MangoLabel(f'{item.name}：{value}'), column, row)
                column += 1
                if index % 3 == 0 and index != 0:
                    row += 1
                    column = 0



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
import math

from mango_ui.init import *


class MangoPagination(QWidget):
    click = Signal(object)

    def __init__(self, parent=None):
        super().__init__()
        self.parent = parent
        self.total_size = 0
        self.page = 1
        self.number_part = 20

        self.current_page_label1 = QLabel(f"共 {self.total_size} 条")

        self.prev_icon_button = QPushButton()
        self.prev_icon_button.setMaximumWidth(30)
        self.prev_icon_button.setEnabled(False)
        self.prev_icon_button.setText('<')

        self.next_icon_button = QPushButton()
        self.next_icon_button.setMaximumWidth(30)
        self.next_icon_button.setText('>')

        # 创建当前页显示的标签
        self.current_page_label = QLabel(f"{self.page}")
        self.items_per_page_combo = QComboBox()
        self.items_per_page_combo.addItems(["10 条/页", "20 条/页", "30 条/页", "50 条/页", "100 条/页"])
        self.items_per_page_combo.setCurrentText("20 条/页")

        # 布局设置
        layout = QHBoxLayout()
        layout.setContentsMargins(0, 0, 0, 0)
        layout.addStretch()
        layout.addWidget(self.current_page_label1)
        layout.addWidget(self.prev_icon_button)
        layout.addWidget(self.current_page_label)
        layout.addWidget(self.next_icon_button)
        layout.addWidget(self.items_per_page_combo)

        self.setLayout(layout)

        self.prev_icon_button.clicked.connect(self.on_prev_page)
        self.next_icon_button.clicked.connect(self.on_next_page)

        self.items_per_page_combo.currentIndexChanged.connect(self.on_items_per_page_changed)
        self.button_enabled()

    def on_prev_page(self):
        self.page -= 1
        self.click.emit({'action': 'prev', 'page': self.page})
        self.current_page_label.setText(str(self.page))
        self.button_enabled()

    def on_next_page(self):
        self.page += 1
        self.click.emit({'action': 'next', 'page': self.page})
        self.current_page_label.setText(str(self.page))
        self.button_enabled()

    def on_items_per_page_changed(self, index):
        selected_text = self.items_per_page_combo.itemText(index)
        self.number_part = int(selected_text.split(" ")[0])
        self.click.emit({'action': 'per_page', 'page': self.number_part})
        self.button_enabled()

    def set_total_size(self, total_size: str):
        self.current_page_label1.setText(f"共 {total_size} 条")
        if total_size:
            self.total_size = int(total_size)
        self.button_enabled()

    def button_enabled(self):
        if self.page > 1:
            self.prev_icon_button.setEnabled(True)
        else:
            self.prev_icon_button.setEnabled(False)
        if self.page >= math.ceil(self.total_size / self.number_part):
            self.next_icon_button.setEnabled(False)
        else:
            self.next_icon_button.setEnabled(True)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-16 15:46
# @Author : 毛鹏
class WidgetTool:

    @staticmethod
    def remove_layout(layout):
        while layout.count() > 0:
            widget = layout.itemAt(0).widget()
            if widget is not None:
                layout.removeWidget(widget)
                widget.deleteLater()



import sys
from PySide6.QtWidgets import QApplication, QWidget, QVBoxLayout
from mango_ui import *



class CronGenerator(QWidget):
    def __init__(self):
        super().__init__()

        self.setWindowTitle("Cron 表达式生成器")
        self.setGeometry(100, 100, 300, 200)

        # 创建布局
        layout = QVBoxLayout()
        h_layout = QHBoxLayout()
        h_layout_2 = QHBoxLayout()

        layout.addLayout(h_layout)
        layout.addLayout(h_layout_2)
        # 创建周几复选框
        self.weekday_checkboxes = []
        weekdays = ["周日", "周一", "周二", "周三", "周四", "周五", "周六"]
        h_layout.addWidget(MangoLabel("选择周几 (可多选):"))

        for day in weekdays:
            checkbox = MangoCheckBox(day)
            self.weekday_checkboxes.append(checkbox)
            h_layout.addWidget(checkbox)

        # 创建时间选择器
        self.time_edit = MangoTimeEdit()
        self.time_edit.setDisplayFormat("HH:mm")  # 设置显示格式为 HH:mm
        h_layout_2.addWidget(MangoLabel("选择时间 (HH:MM):"))
        h_layout_2.addWidget(self.time_edit)

        # 创建提交按钮
        self.submit_button = MangoPushButton("提交")
        self.submit_button.clicked.connect(self.generate_cron)
        layout.addWidget(self.submit_button)

        self.setLayout(layout)

    def generate_cron(self):
        selected_days = []
        for checkbox in self.weekday_checkboxes:
            if checkbox.isChecked():
                selected_days.append(str(self.weekday_checkboxes.index(checkbox)))

        time = self.time_edit.time()
        hour = time.hour()
        minute = time.minute()
        cron_expression = f"{minute} {hour} * * {','.join(selected_days)}"
        print(cron_expression)
        return cron_expression


if __name__ == "__main__":
    app = QApplication(sys.argv)
    window = CronGenerator()
    window.show()
    sys.exit(app.exec())



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-08-30 14:51
# @Author : 毛鹏
from mango_ui.init import *


class MangoDialog(QDialog):
    def __init__(self, tips: str, size: tuple = (400, 300)):
        super().__init__()
        self.setWindowTitle(tips)
        self.setFixedSize(*size)
        self.layout = QVBoxLayout()
        self.setLayout(self.layout)
        self.setWindowIcon(QIcon(':/icons/app_icon.png'))
        # 设置样式表
        self.setStyleSheet(f"""
            QDialog {{
                background-color: {THEME.bg_one}; /* 主体背景颜色 */
            }}
            QDialog::title {{
                background-color: {THEME.dark_one}; /* 标题栏背景颜色 */
                color: {THEME.text_title}; /* 标题栏文字颜色 */
            }}
        """)



from setuptools import setup, find_packages

__version__ = '1.2.1'

with open("README.md", "r", encoding='utf-8') as fh:
    long_description = fh.read()

setup(
    name='MangoUi',
    version=__version__,
    description='UI组件库',
    long_description=long_description,
    # package_data={
    #     'mangokit.mango': ['mango.cp310-win_amd64.pyd'],
    # },
    author='毛鹏',
    author_email='729164035@qq.com',
    url='https://gitee.com/mao-peng/MangoUi',
    packages=find_packages(),
    install_requires=[
        'pydantic~=2.9.2',
        'pyside6~=6.7.0',
        'matplotlib~=3.9.2',
        'numpy~=2.1.2',
        'pyqtgraph~=0.13.7'
    ],
    classifiers=[
        "Programming Language :: Python :: 3.10",
    ]
)

r"""
pyside6-rcc D:\GitCode\MangoUi\mango_ui\resources\resources.qrc -o D:\GitCode\MangoUi\mango_ui\resources\app_rc.py

python -m pip install --upgrade setuptools wheel
python -m pip install --upgrade twine

python setup.py check
python setup.py sdist bdist_wheel
twine upload --repository-url https://upload.pypi.org/legacy/ dist/*

"""



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-08-28 16:33
# @Author : 毛鹏
from mango_ui import *
from mango_ui.init import *


class ComponentPage(QWidget):
    def __init__(self, central_widget):
        super().__init__()
        # self.hide_grips = False  # 显示四周顶点
        self.central_widget = central_widget
        self.page_2_layout = QVBoxLayout(self)
        self.page_2_layout.setSpacing(5)
        self.page_2_layout.setContentsMargins(5, 5, 5, 5)
        self.scroll_area = QScrollArea(self)
        self.scroll_area.setStyleSheet(u"background: transparent;")
        self.scroll_area.setFrameShape(QFrame.NoFrame)
        self.scroll_area.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
        self.scroll_area.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
        self.scroll_area.setWidgetResizable(True)
        self.contents = QWidget()
        self.contents.setGeometry(QRect(0, 0, 840, 580))
        self.contents.setStyleSheet(u"background: transparent;")
        self.verticalLayout = QVBoxLayout(self.contents)
        self.verticalLayout.setSpacing(15)
        self.verticalLayout.setContentsMargins(5, 5, 5, 5)
        self.title_label = QLabel(self.contents)
        self.title_label.setText(QCoreApplication.translate("PagesWindow", u"页面组件", None))

        self.title_label.setMaximumSize(QSize(16777215, 40))
        font = QFont()
        font.setPointSize(16)
        self.title_label.setFont(font)
        self.title_label.setStyleSheet(u"font-size: 16pt")
        self.title_label.setAlignment(Qt.AlignCenter)
        self.verticalLayout.addWidget(self.title_label)
        self.description_label = QLabel(self.contents)
        self.description_label.setAlignment(Qt.AlignHCenter | Qt.AlignTop)
        self.description_label.setText(QCoreApplication.translate("组件中心",
                                                                  u"以下是所有自定义小部件\n"
                                                                  "哈哈哈哈哈",
                                                                  None))
        self.description_label.setWordWrap(True)
        self.verticalLayout.addWidget(self.description_label)
        self.row_1_layout = QHBoxLayout()
        self.verticalLayout.addLayout(self.row_1_layout)
        self.row_2_layout = QHBoxLayout()
        self.verticalLayout.addLayout(self.row_2_layout)
        self.row_3_layout = QHBoxLayout()
        self.verticalLayout.addLayout(self.row_3_layout)
        self.row_4_layout = QVBoxLayout()
        self.verticalLayout.addLayout(self.row_4_layout)
        self.row_5_layout = QVBoxLayout()
        self.verticalLayout.addLayout(self.row_5_layout)
        self.scroll_area.setWidget(self.contents)
        self.page_2_layout.addWidget(self.scroll_area)

        self.setup_gui()

    def setup_gui(self):
        self.circular_progress_1 = MangoCircularProgress(
            value=80,
            font_size=14,
        )
        self.circular_progress_1.setFixedSize(200, 200)

        # CIRCULAR PROGRESS 2
        self.circular_progress_2 = MangoCircularProgress(
            value=45,
            progress_width=4,
            font_size=14,
        )
        self.circular_progress_2.setFixedSize(160, 160)

        # CIRCULAR PROGRESS 3
        self.circular_progress_3 = MangoCircularProgress(
            value=75,
            progress_width=2,
            font_size=14,
        )
        self.circular_progress_3.setFixedSize(140, 140)

        # PY SLIDER 1
        self.vertical_slider_1 = MangoSlider(
            margin=8,
            bg_size=10,
            bg_radius=5,
            handle_margin=-3,
            handle_size=16,
            handle_radius=8,
        )
        self.vertical_slider_1.setMinimumHeight(100)

        # PY SLIDER 2
        self.vertical_slider_2 = MangoSlider()
        self.vertical_slider_2.setMinimumHeight(100)

        # PY SLIDER 3
        self.vertical_slider_3 = MangoSlider(
            margin=8,
            bg_size=10,
            bg_radius=5,
            handle_margin=-3,
            handle_size=16,
            handle_radius=8,
        )
        self.vertical_slider_3.setOrientation(Qt.Horizontal)
        self.vertical_slider_3.setMaximumWidth(200)

        # PY SLIDER 4
        self.vertical_slider_4 = MangoSlider()
        self.vertical_slider_4.setOrientation(Qt.Horizontal)
        self.vertical_slider_4.setMaximumWidth(200)

        # ICON BUTTON 1
        self.icon_button_1 = MangoIconButton(
            parent=self,
            app_parent=self.central_widget,
            tooltip_text="Icon button - Heart",
            width=40,
            height=40,
            radius=20,
        )

        # ICON BUTTON 2
        self.icon_button_2 = MangoIconButton(
            parent=self,
            app_parent=self.central_widget,
            tooltip_text="BTN with tooltip",
            width=40,
            height=40,
            radius=8,
            dark_one=THEME.dark_one,
            icon_color=THEME.icon_color,
            icon_color_hover=THEME.icon_hover,
            icon_color_pressed=THEME.white,
            icon_color_active=THEME.icon_active,
            bg_color=THEME.dark_one,
            bg_color_hover=THEME.dark_three,
            bg_color_pressed=THEME.green,
        )

        # ICON BUTTON 3
        self.icon_button_3 = MangoIconButton(
            icon_path=":/icons/icon_add_user.svg",
            parent=self,
            app_parent=self.central_widget,
            tooltip_text="BTN actived! (is_actived = True)",
            width=40,
            height=40,
            radius=8,
            dark_one=THEME.dark_one,
            icon_color=THEME.icon_color,
            icon_color_hover=THEME.icon_hover,
            icon_color_pressed=THEME.white,
            icon_color_active=THEME.icon_active,
            bg_color=THEME.dark_one,
            bg_color_hover=THEME.dark_three,
            bg_color_pressed=THEME.context_color,
            is_active=True
        )

        # PUSH BUTTON 1
        self.push_button_1 = MangoPushButton(
            text="Button Without Icon",
        )
        self.push_button_1.setMinimumHeight(40)

        # PUSH BUTTON 2
        self.push_button_2 = MangoPushButton(
            text="Button With Icon",

        )
        self.icon_2 = QIcon(":/icons/settings.svg")
        self.push_button_2.setMinimumHeight(40)
        self.push_button_2.setIcon(self.icon_2)

        # PY LINE EDIT
        self.line_edit = MangoLineEdit("Place holder text", "", )
        self.line_edit.setMinimumHeight(30)

        # TOGGLE BUTTON
        self.toggle_button = MangoToggle(
        )

        # TABLE WIDGETS
        # self.table_widget = MangoTableWidget()
        # self.table_widget.setColumnCount(3)
        # self.table_widget.horizontalHeader().setSectionResizeMode(QHeaderView.Stretch)
        # self.table_widget.setSelectionMode(QAbstractItemView.ExtendedSelection)
        # self.table_widget.setSelectionBehavior(QAbstractItemView.SelectRows)

        # Columns / Header
        # self.column_1 = QTableWidgetItem()
        # self.column_1.setTextAlignment(Qt.AlignCenter)
        # self.column_1.setText("NAME")
        #
        # self.column_2 = QTableWidgetItem()
        # self.column_2.setTextAlignment(Qt.AlignCenter)
        # self.column_2.setText("NICK")
        #
        # self.column_3 = QTableWidgetItem()
        # self.column_3.setTextAlignment(Qt.AlignCenter)
        # self.column_3.setText("PASS")
        #
        # # Set column
        # self.table_widget.setHorizontalHeaderItem(0, self.column_1)
        # self.table_widget.setHorizontalHeaderItem(1, self.column_2)
        # self.table_widget.setHorizontalHeaderItem(2, self.column_3)
        #
        # for x in range(10):
        #     row_number = self.table_widget.rowCount()
        #     self.table_widget.insertRow(row_number)  # Insert row
        #     self.table_widget.setItem(row_number, 0, QTableWidgetItem(str("Wanderson")))  # Add name
        #     self.table_widget.setItem(row_number, 1, QTableWidgetItem(str("vfx_on_fire_" + str(x))))  # Add nick
        #     self.pass_text = QTableWidgetItem()
        #     self.pass_text.setTextAlignment(Qt.AlignCenter)
        #     self.pass_text.setText("12345" + str(x))
        #     self.table_widget.setItem(row_number, 2, self.pass_text)  # Add pass
        #     self.table_widget.setRowHeight(row_number, 22)

        # ADD WIDGETS
        self.row_1_layout.addWidget(self.circular_progress_1)
        self.row_1_layout.addWidget(self.circular_progress_2)
        self.row_1_layout.addWidget(self.circular_progress_3)
        self.row_2_layout.addWidget(self.vertical_slider_1)
        self.row_2_layout.addWidget(self.vertical_slider_2)
        self.row_2_layout.addWidget(self.vertical_slider_3)
        self.row_2_layout.addWidget(self.vertical_slider_4)
        self.row_3_layout.addWidget(self.icon_button_1)
        self.row_3_layout.addWidget(self.icon_button_2)
        self.row_3_layout.addWidget(self.icon_button_3)
        self.row_3_layout.addWidget(self.push_button_1)
        self.row_3_layout.addWidget(self.push_button_2)
        self.row_3_layout.addWidget(self.toggle_button)
        self.row_4_layout.addWidget(self.line_edit)
        # self.row_5_layout.addWidget(self.table_widget)

    def load_data(self):
        # 模拟延迟加载数据
        QTimer.singleShot(3000, self.show_data)  # 3秒后调用show_data方法

    def show_data(self):
        pass



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from mango_ui.init import *
from mango_ui.models.models import DialogCallbackModel


class MangoLineEdit(QLineEdit):
    click = Signal(object)
    mouse_remove = Signal(object)

    def __init__(
            self,
            placeholder,
            value: str | None = None,
            subordinate: str | None = None,
            is_password: bool = False,
            theme=THEME,
            **kwargs
    ):
        super().__init__()
        self.editingFinished.connect(self.line_edit_changed)
        self.subordinate = subordinate
        self.value = value
        self.kwargs = kwargs
        self.theme = theme.model_dump()
        if is_password:
            self.setEchoMode(QLineEdit.Password)
        if placeholder:
            self.setPlaceholderText(placeholder)
        self.set_value(self.value)
        self.set_stylesheet(self.theme)

    def get_value(self):
        return self.text()

    def set_value(self, value):
        self.value = value
        if self.value is not None:
            self.setText(str(self.value))

    def line_edit_changed(self, ):
        if self.subordinate:
            self.click.emit(DialogCallbackModel(
                key=self.kwargs.get('key'),
                value=self.text(),
                subordinate=self.subordinate,
                input_object=self
            ))
        else:
            self.click.emit(self.get_value())

    def focusOutEvent(self, event):
        self.click.emit(self.get_value())
        super().focusOutEvent(event)

    def set_stylesheet(self, theme):
        style = f"""
        QLineEdit {{
            background-color: {theme['white']};
            border-radius: {theme['radius']}px;
            border: {theme['border_size']}px solid gray;
            padding-left: 10px;
            padding-right: 10px;
            selection-color: {theme['white']};
            selection-background-color: {theme['context_color']};
            color: {theme['text_foreground']};
        }}

        QLineEdit:focus {{
            border: {theme['border_size']}px solid {theme['context_color']};
            background-color: {theme['dark_three']};
        }}
        """
        self.setStyleSheet(style)
        self.setMinimumHeight(30)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏

from mango_ui.init import *
from mango_ui.models.models import LeftMenuModel
from mango_ui.widgets.menu.mango_left_menu.mango_div import MangoDiv
from mango_ui.widgets.menu.mango_left_menu.mango_left_menu_button import MangoLeftMenuButton


class MangoLeftMenu(QWidget):
    clicked = Signal(object)
    released = Signal(object)

    def __init__(
            self,
            parent=None,
            app_parent=None,
            duration_time=500,
            minimum_width=50,
            maximum_width=180,
            icon_path=":/icons/menu.svg",
            icon_path_close=":/icons/icon_menu_close.svg",
            toggle_text="默认展开",
            toggle_tooltip="展开"
    ):
        super().__init__()
        self.duration_time = duration_time
        self.minimum_width = minimum_width
        self.maximum_width = maximum_width
        self.icon_path = icon_path
        self.icon_path_close = icon_path_close
        self.parent = parent
        self._app_parent = app_parent

        self.left_menu_layout = QVBoxLayout(self)
        self.left_menu_layout.setContentsMargins(0, 0, 0, 0)

        self.bg = QFrame()

        # TOP FRAME
        self.top_frame = QFrame()

        # BOTTOM FRAME
        self.bottom_frame = QFrame()

        # ADD LAYOUTS
        self._layout = QVBoxLayout(self.bg)
        self._layout.setContentsMargins(0, 0, 0, 0)

        # TOP LAYOUT
        self.top_layout = QVBoxLayout(self.top_frame)
        self.top_layout.setContentsMargins(0, 0, 0, 0)
        self.top_layout.setSpacing(1)

        # BOTTOM LAYOUT
        self.bottom_layout = QVBoxLayout(self.bottom_frame)
        self.bottom_layout.setContentsMargins(0, 0, 0, 8)
        self.bottom_layout.setSpacing(1)

        # ADD TOP AND BOTTOM FRAME
        self._layout.addWidget(self.top_frame, 0, Qt.AlignTop)  # type: ignore
        self._layout.addWidget(self.bottom_frame, 0, Qt.AlignBottom)  # type: ignore

        self.left_menu_layout.addWidget(self.bg)

        self.bg.setStyleSheet(f"background: {THEME.dark_one}; border-radius: {THEME.radius};")

        self.toggle_button = MangoLeftMenuButton(
            app_parent,
            text=toggle_text,
            tooltip_text=toggle_tooltip,
            icon_path=icon_path
        )
        # self.toggle_button.clicked.connect(self.toggle_animation)
        self.top_layout.addWidget(self.toggle_button)

        self.div_top = MangoDiv(THEME.dark_one)
        self.top_layout.addWidget(self.div_top)

        self.div_bottom = MangoDiv(THEME.dark_one)
        self.div_bottom.hide()
        self.bottom_layout.addWidget(self.div_bottom)
        self.list_button_frame = {}
        self.toggle_animation()


    def add_menus(self, menu_model: list[LeftMenuModel]):
        for menu_obj in menu_model:
            layout = QVBoxLayout()
            self.menu = MangoLeftMenuButton(
                self._app_parent,
                text=menu_obj.btn_text,
                btn_id=menu_obj.btn_id,
                tooltip_text=menu_obj.btn_tooltip,
                icon_path=menu_obj.btn_icon,
                is_active=menu_obj.is_active,
                url=menu_obj.url
            )
            self.menu.clicked.connect(self.btn_clicked)
            self.menu.released.connect(self.btn_released)
            layout.addWidget(self.menu)

            if menu_obj.submenus:
                button_frame = QFrame()
                button_frame.setStyleSheet("QFrame { border: none; }")
                button_frame.setContentsMargins(0, 0, 0, 0)
                button_frame.hide()
                self.list_button_frame[menu_obj.btn_id] = button_frame
                v_layout = QVBoxLayout(button_frame)
                v_layout.setContentsMargins(0, 0, 0, 0)  # 设置边距为0
                v_layout.setStretch(0, 7)
                for menu in menu_obj.submenus:
                    frame_layout = QHBoxLayout()
                    but = MangoLeftMenuButton(
                        self._app_parent,
                        text=menu.btn_text,
                        btn_id=menu.btn_id,
                        tooltip_text=menu.btn_tooltip,
                        icon_path=None,
                        is_active=menu.is_active
                    )
                    frame_layout.addWidget(but)
                    v_layout.addLayout(frame_layout)
                    but.clicked.connect(self.btn_clicked)
                    but.released.connect(self.btn_released)
                layout.addWidget(button_frame)
            if menu_obj.show_top:
                self.top_layout.addLayout(layout)
            else:
                self.div_bottom.show()
                self.bottom_layout.addLayout(layout)

    def btn_clicked(self, ):
        self.clicked.emit(self.menu)

    def btn_released(self):
        self.released.emit(self.menu)

    def toggle_animation(self):
        self.animation = QPropertyAnimation(self.parent, b"minimumWidth")
        self.animation.stop()
        self.animation.setStartValue(self.width())
        self.animation.setEndValue(self.maximum_width)
        self.toggle_button.set_active_toggle(True)
        self.toggle_button.set_icon(self.icon_path_close)
        # else:
        #     self.animation.setStartValue(self.width())
        #     self.animation.setEndValue(self.minimum_width)
        #     self.toggle_button.set_active_toggle(False)
        #     self.toggle_button.set_icon(self.icon_path)
        self.animation.setEasingCurve(QEasingCurve.InOutCubic)  # type: ignore
        self.animation.setDuration(self.duration_time)
        self.animation.start()

    def select_only_one(self, widget: str):
        for btn in self.findChildren(QPushButton):
            if btn.objectName() == widget:
                btn.set_active(True)
            else:
                btn.set_active(False)

    def select_only_one_tab(self, widget: str):
        for btn in self.findChildren(QPushButton):
            if btn.objectName() == widget:
                btn.set_active_tab(True)
            else:
                btn.set_active_tab(False)

    def deselect_all(self):
        for btn in self.findChildren(QPushButton):
            btn.set_active(False)

    def deselect_all_tab(self):
        for btn in self.findChildren(QPushButton):
            btn.set_active_tab(False)

    # parent = None,
    # app_parent = None,
    # dark_one = THEME.dark_one,
    # dark_three = THEME.dark_three,
    # dark_four = THEME.dark_four,
    # bg_one = THEME.bg_one,
    # icon_color = THEME.icon_color,
    # icon_color_hover = THEME.icon_hover,
    # icon_color_pressed = THEME.icon_pressed,
    # icon_color_active = THEME.icon_active,
    # context_color = THEME.context_color,
    # text_foreground = THEME.text_foreground,
    # text_active = THEME.text_active,
    # duration_time = 500,
    # radius = 8,
    # minimum_width = 50,
    # maximum_width = 180,
    # icon_path = ":/icons/menu.svg",
    # icon_path_close = ":/icons/icon_menu_close.svg",
    # toggle_text = "收起",
    # toggle_tooltip = "展开"
    # self._dark_one = dark_one
    # self._dark_three = dark_three
    # self._dark_four = dark_four
    # self._bg_one = bg_one
    # self._icon_color = icon_color
    # self._icon_color_hover = icon_color_hover
    # self._icon_color_pressed = icon_color_pressed
    # self._icon_color_active = icon_color_active
    # self._context_color = context_color
    # self._text_foreground = text_foreground
    # self._text_active = text_active
    # self._duration_time = duration_time
    # self._radius = radius
    # self._minimum_width = minimum_width
    # self._maximum_width = maximum_width
    # self._icon_path = icon_path
    # self._icon_path_close = icon_path_close



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from mango_ui.init import *

style = """
/* HORIZONTAL */
QSlider {{ margin: {_margin}px; }}
QSlider::groove:horizontal {{
    border-radius: {_bg_radius}px;
    height: {_bg_size}px;
	margin: 0px;
	background-color: {_bg_color};
}}
QSlider::groove:horizontal:hover {{ background-color: {_bg_color_hover}; }}
QSlider::handle:horizontal {{
    border: none;
    height: {_handle_size}px;
    width: {_handle_size}px;
    margin: {_handle_margin}px;
	border-radius: {_handle_radius}px;
    background-color: {_handle_color};
}}
QSlider::handle:horizontal:hover {{ background-color: {_handle_color_hover}; }}
QSlider::handle:horizontal:pressed {{ background-color: {_handle_color_pressed}; }}

/* VERTICAL */
QSlider::groove:vertical {{
    border-radius: {_bg_radius}px;
    width: {_bg_size}px;
    margin: 0px;
	background-color: {_bg_color};
}}
QSlider::groove:vertical:hover {{ background-color: {_bg_color_hover}; }}
QSlider::handle:vertical {{
	border: none;
    height: {_handle_size}px;
    width: {_handle_size}px;
    margin: {_handle_margin}px;
	border-radius: {_handle_radius}px;
    background-color: {_handle_color};
}}
QSlider::handle:vertical:hover {{ background-color: {_handle_color_hover}; }}
QSlider::handle:vertical:pressed {{ background-color: {_handle_color_pressed}; }}
"""


class MangoSlider(QSlider):
    def __init__(
            self,
            margin=0,
            bg_size=20,
            bg_radius=10,
            bg_color=THEME.dark_three,
            bg_color_hover=THEME.dark_four,
            handle_margin=2,
            handle_size=16,
            handle_radius=8,
            handle_color=THEME.context_color,
            handle_color_hover=THEME.context_hover,
            handle_color_pressed=THEME.context_pressed
    ):
        super(MangoSlider, self).__init__()

        adjust_style = style.format(
            _margin=margin,
            _bg_size=bg_size,
            _bg_radius=bg_radius,
            _bg_color=bg_color,
            _bg_color_hover=bg_color_hover,
            _handle_margin=handle_margin,
            _handle_size=handle_size,
            _handle_radius=handle_radius,
            _handle_color=handle_color,
            _handle_color_hover=handle_color_hover,
            _handle_color_pressed=handle_color_pressed
        )

        self.setStyleSheet(adjust_style)
